<script src="../../../assets/deployggb.js"></script>
<script src="../../../assets/graphs.js"></script>
<script>
    window.graphs(
        [
            [
                "example",
                [
                    "f(x) = (x^4 - 1)^2",
                    "f'(x)"
                ]
            ],
            [
                "distance-time",
                [
                    "t(x) = sqrt(x)",
                    "t'"
                ],
                (api) =>
                {
                    api.setAxisUnits(1, "h", "km");
                }
            ],
            [
                "detect",
                [
                    "f(x) = (x + 1)(x - 1)(x - 2)",
                    "f'",
                    "ComplexRoot(f')",
                    "Extremum(f)",
                    "s_1 = Line(A, z_2)",
                    "s_2 = Line(B, z_1)"
                ],
                (api) =>
                {
                    api.setColor("s_1", 0, 128, 0);
                    api.setColor("s_2", 0, 128, 0);
                    api.setLineStyle("s_1", 1);
                    api.setLineStyle("s_2", 1);
                }
            ]
        ]);
</script>

# Ableitungen
Die Ableitung einer Funktion sagt aus, wie sich die Werte der Funktion an einer gegebenen Stelle verändern.

<div id="example"></div>

Wie zu sehen ist, zeigt $f'(x)$ an Stellen, an denen $f(x)$ eine Steigung hat, einen positiven Wert, an Stellen, an denen $f(x)$ keine Steigung hat, $0$ und an Stellen, an denen $f(x)$ sich senkt, einen negativen Wert.

Ableitungen werden jeweils als den Funktions-Namen zusammen mit einem Apostroph geschrieben. So heisst also beispielsweise die Ableitung der Funktion $z(x)$ üblicherweise $z'(x)$.

> **_Note:_**  
> Will man die Ableitung eines Terms ausdrücken, so macht man das folgendermassen:
>
> Die Ableitung von $420x - 1337x^2$ ist $(420x - 1337x^2)'$.

## Inhaltsverzeichnis
- [Ableitungen](#ableitungen)
  - [Inhaltsverzeichnis](#inhaltsverzeichnis)
  - [Realbeispiel](#realbeispiel)
  - [Ableitungen erkennen](#ableitungen-erkennen)
  - [Zweite, Dritte, $n$. Ableitung](#zweite-dritte-n-ableitung)
  - [Ableitungs-Regeln](#ableitungs-regeln)
    - [Allgemeine Regeln](#allgemeine-regeln)
      - [Konstante](#konstante)
      - [Faktor-Regel](#faktor-regel)
      - [Potenz-Regel](#potenz-regel)
      - [Summen-Regel](#summen-regel)
      - [Produkt-Regel](#produkt-regel)
      - [Quotienten-Regel](#quotienten-regel)
      - [Ketten-Regel](#ketten-regel)
    - [Ableitungen bestimmter Funktionen](#ableitungen-bestimmter-funktionen)

## Realbeispiel
Die Ableitung kann beispielsweise verwendet werden, um die Geschwindigkeit einer Bewegung abzubilden.

Folgendes Weg-Zeit-Diagramm soll das verdeutlichen:

<div id="distance-time"></div>

Nicht nur zeigt hier $t'$ die Ableitung der Funktion $t$ auf, sondern auch jeweils die momentane Geschwindigkeit, die eine Person zum gegebenen Zeitpunkt hat.

## Ableitungen erkennen
Ableitungen kann man daran erkennen, dass sie jeweils an den Stellen, an denen die abzuleitende Funktion einen Scheitelpunkt erreicht, einen Wert von $0$ haben, da an diesen Stellen weder eine Senkung noch eine Steigung vorherrscht.

Beispiel:

<div id="detect"></div>

## Zweite, Dritte, $n$. Ableitung
Erstellt man eine Ableitung einer bereits existierenden Ableitung, so nennt sich diese "Zweite Ableitung". Dessen Ableitung wiederum heisst "Dritte Ableitung" etc.

> **_In Worten:_**  
>   - $f'$ ist die Ableitung von $f$
>   - $f''$ ist die Ableitung von $f'$ und somit die **Zweite Ableitung** von $f$
>   - $f'''$ ist die Ableitung von $f''$ und somit die **Dritte Ableitung** von $f$

## Ableitungs-Regeln
Um von einer Funktion (oder Bruchteilen davon) die Ableitung zu errechnen, können einige allgemeingültige Regeln zugezogen werden, welche im Folgenden erklärt werden.

Hilfreiche Links für's Nachschlagen der Regeln:
  - https://www.mathebibel.de/ableitungsregeln
  - https://www.youtube.com/watch?v=GtVWdeevZpw

### Allgemeine Regeln
#### Konstante
Besteht in der Funktion nur eine Konstante ohne ein $x$, so ist dessen Ableitung immer $0$:

| Funktion          | Ableitung   |
| ----------------- | ----------- |
| $f(x) = 1337$     | $f'(x) = 0$ |
| $f(x) = \sqrt{2}$ | $f'(x) = 0$ |

#### Faktor-Regel
Die Faktor-Regel besagt, dass konstante Zahlen, mit denen $x$ multipliziert werden, auch in dessen Ableitung bestehen bleiben.

> $$f(x) = c \cdot x \rightarrow f'(x) = c \cdot (x)'$$

Das bedeutet folgendes:

Wenn $f(x)$ folgender Funktion entspricht:

$f(x) = 2 \cdot g(x)$ und $g(x) = x$

So ist die Ableitung davon folgende:
$$f(x) = 2 \cdot g'(x)$$

| Funktion    | Ableitung |
| ----------- | --------- |
| $f(x) = 7x$ | $7$       |

#### Potenz-Regel
Die Potenzregel lautet folgendermassen: 

> $$f(x) = x^n \rightarrow f'(x) = n \cdot x^{n - 1}$$

Auch hier wieder anhand einiger Beispiele:

| Funktion      | Ableitung               |
| ------------- | ----------------------- |
| $f(x) = x$    | $1$                     |
| $f(x) = x^7$  | $7 \cdot x^6$           |
| $f(x) = x^6$  | $6 \cdot x^5$           |
| $f(x) = 3x^6$ | $3 \cdot (6 \cdot x^5)$ |

#### Summen-Regel
Die Ableitung einer Addition ergibt die Summe der Ableitung der einzelnen Summanden der Addition:

> $$f(x) = g(x) + h(x) \rightarrow f'(x) = g'(x) + h'(x)$$

Diese Regel ist auch auf Subtraktionen anwendbar:

> $$f(x) = g(x) - h(x) \rightarrow f'(x) = g'(x) - h'(x)$$

Diese Regel kann für jegliche Funktion, welche eine Addition beinhaltet, angewendet werden:

$$f(x) = \overbrace{2x}^{g(x) = 2x} + \overbrace{4x^3}^{h(x) = 4x^3}$$
$$f'(x) = g'(x) + h'(x)$$
$$f'(x) = \underbrace{2 \cdot 1 \cdot x^0}_{g'(x) = 2 \cdot 1 \cdot x^0} + \underbrace{4 \cdot 3 \cdot x^2}_{h'(x) = 4 \cdot 3 \cdot x^2}$$

#### Produkt-Regel
Die Produkt-Regel beschreibt, wie eine Ableitung einer Funktion gemacht werden kann, welche eine Multiplikation beinhaltet.

> $$f(x) = g(x) \cdot h(x) \rightarrow f'(x) = g'(x) \cdot h(x) + g(x) \cdot h'(x)$$

Auch hier wiederum ein Beispiel:
$$f(x) = \overbrace{(3x^3 + x^2)}^{g(x) = 3x^3 + x^2}\overbrace{(4x^2 + 1)}^{h(x) = 4x^2 + 1}$$
$$f'(x) = g'(x) \cdot h'(x)$$
$$f'(x) = \underbrace{(3 \cdot 3 x^2 + 1 \cdot x^1)}_{g'(x) = 3 \cdot 3 x^2 + 1 \cdot x^1} \cdot \overbrace{(4x^2 + 1)}^{h(x)} + \overbrace{(3x^3 + x^2)}^{g(x)} \cdot \underbrace{(4 \cdot 2 \cdot x^1 + 0)}_{h'(x) = 4 \cdot 2 \cdot x^1 + 0}$$

#### Quotienten-Regel
Von der Produkt-Regel lässt sich auch die Quotienten-Regel ableiten. Diese beschreibt, wie man die Ableitung von Divisionen bilden kann und lautet folgendermassen:

> $$f(x) = \frac{g(x)}{h(x)} \rightarrow \frac{g'(x) \cdot h(x) - g(x) \cdot h'(x)}{(h(x))^2}$$

Wie diese Regel angewendet wird, lässt sich anhand des folgenden Beispiels aufzeigen:

$$f(x) = \left(\frac{\overbrace{3x^2 - x}^{g(x)}}{\underbrace{2x^3 + 1}_{h(x)}}\right)$$
$$f'(x) = \frac{g'(x) \cdot h(x) - g(x) \cdot h'(x)}{(h(x))^2}$$
$$f'(x) = \frac{\overbrace{(3 \cdot 2 \cdot x^1 - 1 \cdot x^0)}^{g'(x)} \cdot \overbrace{(2x^3 + 1)}^{h(x)} - \overbrace{(3x^2 - x)}^{g(x)} \cdot \overbrace{(2 \cdot 3 \cdot x^2 + 0)}^{h'(x)}}{(\underbrace{2x^3 + 1}_{h(x)})^2}$$

#### Ketten-Regel
Die Ketten-Regel zeigt auf, wie die Ableitung von verschachtelten Funktionen geformt werden kann.

Folgende Regel gilt:

> $$f(x) = g(h(x)) \rightarrow f'(x) = g'(h(x)) \cdot h'(x)$$

Aufgezeigt anhand eines Beispiels:

$$f(x) = \overbrace{(\underbrace{x^3 + 4}_{h(x) = x^3 + 4})^{-2}}^{g(x) = x^{-2}}$$
$$f'(x) = g'(h(x)) \cdot h'(x)$$
$$f'(x) = \overbrace{-2 \cdot (\underbrace{x^3 + 4}_{h(x)})^{-3}}^{g'(h(x))} \cdot \overbrace{(3 \cdot x^2 + 0)}^{h'(x)}$$

### Ableitungen bestimmter Funktionen
Folgende Auflistung zeigt einige bekannte Funktionen und deren Ableitung auf.

$a$ steht hierbei für eine Konstante.

| Ausdruck       | Ableitung                  |
| -------------- | -------------------------- |
| $(\sin(x))'$   | $\cos(x)$                  |
| $(\cos(x))'$   | $-\sin(x)$                 |
| $(e^x)'$       | $e^x$                      |
| $(a^x)'$       | $a^x \cdot \ln(a)$         |
| $(\ln(x))'$    | $\frac{1}{x}$              |
| $(\log_a(x))'$ | $\frac{1}{x \cdot \ln(a)}$ |
